/***************************************************************************************************/
#ifndef INC_IDOTSCENELOADERIMPL020_H
#define INC_IDOTSCENELOADERIMPL020_H
/***************************************************************************************************/
#include "IDotSceneLoaderImpl.h"
/***************************************************************************************************/
namespace Ogre
{
	/***************************************************************************************************/
	namespace dsi
	{
		/***************************************************************************************************/
		class dotSceneLoaderImpl020 : public IDotSceneLoaderImpl
		{
		public:
			dotSceneLoaderImpl020();
			~dotSceneLoaderImpl020();
			/// the only thing we must implement in loader is load ;)
			void load(
				OBT::TiXmlDocument *pXMLDoc, 
				SceneManager *pSceneManager, 
				RenderWindow *pRWin, 
				const String &groupName,
				SceneNode *pRootNode = NULL, 
				bool doMaterials = false, 
				bool forceShadowBuffers = false, 
				bool updateDSInfo = false);

		private:
			struct sHWGPUBuffer
			{
				/// members
				Ogre::HardwareBuffer::Usage usage;
				bool						shadow;
				/// def. ctor
				sHWGPUBuffer()
				{
					usage = Ogre::HardwareBuffer::HBU_STATIC_WRITE_ONLY;
					shadow = true;
				}
			};
			sHWGPUBuffer *_getHwGpuBuffer(OBT::TiXmlElement *pNode);

			void _doNodes(OBT::TiXmlElement *pNode);
			void _doNode(SceneNode *pParent, OBT::TiXmlElement *pNode);
			void _doAnimations(SceneNode *pParent, OBT::TiXmlElement *pNode);
			void _doAnimation(SceneNode *pParent, OBT::TiXmlElement *pNode);
	    void _doKeyframe( NodeAnimationTrack* track, 	OBT::TiXmlElement *pNode);
      void _doEnvironment(OBT::TiXmlElement *pNode);
			void _doEntity(SceneNode *pParent, OBT::TiXmlElement *pNode);
			void _doLight(SceneNode *pParent, OBT::TiXmlElement *pNode);
			void _doViewport(SceneNode *pParent, OBT::TiXmlElement *pNode);
			void _doCamera(SceneNode *pParent, OBT::TiXmlElement *pNode);
			void _doBillboardSet(SceneNode *pParent, OBT::TiXmlElement *pNode);
			void _doBillboard(BillboardSet *pParent, OBT::TiXmlElement *pNode);
      void _doParticleSystem(SceneNode *pParent, OBT::TiXmlElement *pNode);
      void _doPlane(SceneNode *pParent, OBT::TiXmlElement *pNode);
			void _doSkyBox(OBT::TiXmlElement *pNode);
			void _doSkyDome(OBT::TiXmlElement *pNode);
			void _doSkyPlane(OBT::TiXmlElement *pNode);
			void _doClipping(OBT::TiXmlElement *pNode, Real &near, Real &far);
			void _doFog(OBT::TiXmlElement *pNode);
			void _doTerrain(OBT::TiXmlElement *pNode);
			void _doExternals(OBT::TiXmlElement *pNode);
			void _doItem(OBT::TiXmlElement *pNode);
			void _doLightAttenuation(OBT::TiXmlElement *pElem, Real &range, Real &constant, Real &linear, Real &quadratic);
			void _doLightRange(OBT::TiXmlElement *pElem, Real &inner, Real &outer, Real &falloff);
			void _doScene(SceneNode *pParent, OBT::TiXmlElement *pNode);
			void _updateDSI(Ogre::MovableObject *pMO, Ogre::Vector3 &pos, Ogre::Quaternion &rot, Ogre::Vector3 &scale, bool isStatic);
      //Add Shadow
			void _doShadowProperties(OBT::TiXmlElement *pNode);
			// those only queue parsing of targets later...
			void _doSNLTarget(OBT::TiXmlElement *pElem, SceneNode *pSN);
			void _doSNTTarget(OBT::TiXmlElement *pElem, SceneNode *pSN);
			void _doCamLTarget(OBT::TiXmlElement *pElem, Camera *pCam);
			void _doCamTTarget(OBT::TiXmlElement *pElem, Camera *pCam);

			// those parse targets ...
			void __doSNLTarget(OBT::TiXmlElement *pElem, SceneNode *pSN);
			void __doSNTTarget(OBT::TiXmlElement *pElem, SceneNode *pSN);
			void __doCamLTarget(OBT::TiXmlElement *pElem, Camera *pCam);
			void __doCamTTarget(OBT::TiXmlElement *pElem, Camera *pCam);

			bool _getAttribute(OBT::TiXmlElement *pElem, const String &attribute, String &attributeValue);
			bool _getAttribute(OBT::TiXmlElement *pElem, const String &attribute, bool &attributeValue);
			bool _getAttribute(OBT::TiXmlElement *pElem, const String &attribute, Real &attributeValue);
      //Modify Name according OMK syntaxe and SceneGraph nodes
      Ogre::String setName(const Ogre::String & original, const Ogre::String& type, Ogre::SceneManager* smgr);

			Ogre::String _doFile(OBT::TiXmlElement *pNode);
			Ogre::String _getNodeName(OBT::TiXmlElement *pNode);
			Ogre::String _autoName();
       
		private:
			SceneNode		*mpRoot;
			SceneManager	*mpSceneManager;
			RenderWindow	*mpWin;
			bool			mDoMats;
			bool			mShadow;
			bool			mDoInfo;
			std::map< String, unsigned short> _viewportsNameToIndexMap ;
		};
		/***************************************************************************************************/
	} // namespace dsi
	/***************************************************************************************************/
} // namespace Ogre
/***************************************************************************************************/
#endif // #ifndef INC_IDOTSCENELOADERIMPL020_H
/***************************************************************************************************/
