/***************************************************************************************************/
#ifndef INC_DOTSCENESERIALIZER_H
#define INC_DOTSCENESERIALIZER_H
/***************************************************************************************************/
#include <OBTtinyxml.h>
/***************************************************************************************************/
#include "dotSceneInfo.h"
/***************************************************************************************************/
namespace Ogre
{
	/***************************************************************************************************/
	namespace dsi
	{
		/** 
		anything in the scene (nodes, lights, cameras, movables, entities, billboardSets...)
		that use this string as a part of the 
		name or as a name will not be serialized by the dotScene serializer
		**/
		static Ogre::String nonDSIPrefix = "nonDSI.";
		/***************************************************************************************************/
		class DOTSCENEINTERFACE_API dotSceneSerializer : public Singleton<dotSceneSerializer>, public types::progressMaker
		{
		public:
			dotSceneSerializer();
			virtual ~dotSceneSerializer();
			dotSceneSerializer &getSingleton(void);
			void saveScene(const Ogre::String &fileName, SceneManager *pSceneManager, bool doStatic,bool doEnvironment = true);
			OBT::TiXmlDocument *parseScene(SceneManager *pSceneManager, bool doStatic);

		private:
			unsigned long		mID;
			Ogre::SceneManager	*mpSceneManager;

			void _removeEmptySceneNodes(OBT::TiXmlDocument *pXMLDoc);
			void __removeEmptySceneNodes(OBT::TiXmlElement *pNodes);
			void _doNodes(OBT::TiXmlElement *pParent, bool doStatic);
			void _doNode(OBT::TiXmlElement *pParent, Ogre::SceneNode *pNode, bool doStatic);
			void _doEnvironment(OBT::TiXmlElement *pParent);
			void _doEntity(OBT::TiXmlElement *pParent, Entity *pEnt, bool doStatic);
			void _doLight(OBT::TiXmlElement *pParent, Light *pLight);
			void _doCamera(OBT::TiXmlElement *pParent, Camera *pCam);
			void _doBillboardSet(OBT::TiXmlElement *pParent, BillboardSet *pBS);
			void _doBillboard(OBT::TiXmlElement *pParent, Billboard *pBill);
			void _doSkyBox(OBT::TiXmlElement *pParent, types::skyBox *pSB);
			void _doSkyDome(OBT::TiXmlElement *pParent, types::skyDome *pSD);
			void _doSkyPlane(OBT::TiXmlElement *pParent, types::skyPlane *pSP);
			void _doClipping(OBT::TiXmlElement *pParent, Real fcd, Real ncd);
			void _doFog(OBT::TiXmlElement *pParent);
	    std::string getNameWithoutDelimiterOMK(const std::string& name);
    };
		/***************************************************************************************************/
	} // namespace dsi
	/***************************************************************************************************/
} // namespace Ogre
/***************************************************************************************************/
#endif // #ifndef INC_DOTSCENESERIALIZER_H
/***************************************************************************************************/
